@@ -42,7 +42,7 @@ class FireServiceRota(object):
 
 
     def request_tokens(self) -> bool:
-        """Get API tokens."""
+        """Request API tokens."""
 
         oauth_client = oauthlib.oauth2.LegacyApplicationClient(client_id=None)
         request_body = oauth_client.prepare_request_body(
@@ -61,7 +61,7 @@ class FireServiceRota(object):
 
 
     def refresh_tokens(self) -> bool:
-        """Refresh API tokens."""
+        """Refresh existing API tokens."""
 
         if not self._token_info:
            return
@@ -134,9 +134,9 @@ class FireServiceRota(object):
         url = FSR_ENDPOINT_INCIDENT_RESPONSES.format(id)
 
         if status:
-            json = {'status': 'acknowledged'}
+            json = {'status': 'acknowledged', 'channel': 'home-assistant'}
         else:
-            json = {'status': 'rejected'}
+            json = {'status': 'rejected', 'channel': 'home-assistant'}
 
         self._request('POST', endpoint=url, log_msg_action='set incident response', params=json, auth_request=False)
         
@@ -195,17 +195,6 @@ class FireServiceRota(object):
         return interval
 
 
-    def update(self, id):
-
-        incident_response = {}
-        availability = self.get_availability()
-
-        if id:
-            incident_response = self.get_incident_response(id)
-
-        return ({**availability,**incident_response})
-
-
     def _request(
         self,
         method: str,
