@@ -1,7 +1,4 @@
 """Constants used."""
-import logging
-
-_LOGGER = logging.getLogger("pyfireservicerota")
 
 FSR_DEFAULT_TIMEOUT = 20
 FSR_ENDPOINT_TOKEN = "oauth/token"
